@@ -8,14 +8,14 @@ fixsome <- function(x, exo.fix=TRUE, measurement.fix=TRUE, S, mu, n, data, x0=FA
         paramval <- c("hybrid","relative","none","absolute")
         param <- agrep(param,paramval,max.distance=0,value=TRUE)
     }
-    
+
     if (is.character(measurement.fix)) {
         param <- measurement.fix
         measurement.fix <- TRUE
     }
     var.missing <- c()
     if (!missing(data) | !missing(S)) {
-        
+
         if (!missing(data)) {
             dd <- procdata.lvm(x,data=data,na.method=na.method)
         } else {
@@ -24,7 +24,7 @@ fixsome <- function(x, exo.fix=TRUE, measurement.fix=TRUE, S, mu, n, data, x0=FA
         S <- dd$S; mu <- dd$mu; n <- dd$n
         var.missing <- setdiff(index(x)$manifest,colnames(S))
     } else { S <- NULL; mu <- NULL }
-    
+
     if (measurement.fix & param!="none") {
         if (length(var.missing)>0) {## Convert to latent:
             new.lat <- setdiff(var.missing,latent(x))
@@ -37,19 +37,19 @@ fixsome <- function(x, exo.fix=TRUE, measurement.fix=TRUE, S, mu, n, data, x0=FA
 
         for (e in etas) { ## Makes sure that at least one arrow from latent variable is fixed (identification)
             ys. <- names(which(M[e,ys]==1))
-            if (length(ys.)>0) {      
+            if (length(ys.)>0) {
                 if (tolower(param)=="absolute") {
                     if (is.na(intercept(x)[[e]])) intercept(x,e) <- 0
                     if (is.na(x$covfix[e,e]) & is.na(x$covpar[e,e])) covariance(x,e) <- 1
-                } else {        
+                } else {
                     if (param=="hybrid") {
                         if (is.na(intercept(x)[[e]])) intercept(x,e) <- 0
                         if (all(is.na(x$fix[e, ]==1)) &
-                            is.na(x$covpar[e,e]) & is.na(x$covfix[e,e])) 
+                            is.na(x$covpar[e,e]) & is.na(x$covfix[e,e]))
                             regfix(x,from=e,to=ys.[1]) <- 1
                     } else { ## relative
                         if (all(is.na(x$fix[e, ]==1)) &
-                            is.na(x$covpar[e,e]) & is.na(x$covfix[e,e])) 
+                            is.na(x$covpar[e,e]) & is.na(x$covfix[e,e]))
                             regfix(x,from=e,to=ys.[1]) <- 1
                         if (!any(unlist(lapply(intercept(x)[ys.],is.numeric))) &
                             is.na(intercept(x)[[e]]))
@@ -64,7 +64,7 @@ fixsome <- function(x, exo.fix=TRUE, measurement.fix=TRUE, S, mu, n, data, x0=FA
     if (exo.fix) {
         if (x0) {
             S0 <- diag(length(index(x)$manifest))
-            mu0 <- rep(0,nrow(S0))      
+            mu0 <- rep(0,nrow(S0))
         }
         else {
             S0 <- S
@@ -77,12 +77,12 @@ fixsome <- function(x, exo.fix=TRUE, measurement.fix=TRUE, S, mu, n, data, x0=FA
         exo.idx <- index(x)$exo.obsidx;
         exo_all.idx <- index(x)$exo.idx
         if (length(exo.idx)>0) {
-            for (i in 1:length(exo.idx))
-                for (j in 1:length(exo.idx)) {
+            for (i in seq_along(exo.idx))
+                for (j in seq_along(exo.idx)) {
                     i. <- exo_all.idx[i]; j. <- exo_all.idx[j]
-                    myval <- S0[exo.idx[i],exo.idx[j]];          
+                    myval <- S0[exo.idx[i],exo.idx[j]];
                     if (i.==j. & myval==0) {
-                        ##warning("Overparametrized model. Problem with '"%+%index(x)$vars[j.]%+%"'")
+                        ##warning("Overparametrized model. Problem with '"%++%index(x)$vars[j.]%++%"'")
                         myval <- 1
                     }
                     else if (is.na(myval) || is.nan(myval)) myval <- 0
@@ -91,7 +91,7 @@ fixsome <- function(x, exo.fix=TRUE, measurement.fix=TRUE, S, mu, n, data, x0=FA
             x$mean[exo_all.idx] <- mu0[exo.idx]
         }
     }
-    
-    index(x) <- reindex(x)  
+
+    index(x) <- reindex(x)
     return(x)
 }
