@@ -30,6 +30,7 @@
 ##' @param vcov Optional variance estimates
 ##' @param predictfun Optional predict-function used to calculate confidence limits and predictions
 ##' @param plot If FALSE return only predictions and confidence bands
+##' @param new If FALSE add to current plot
 ##' @param \dots additional arguments to lower level functions
 ##' @return list with following members:
 ##' \item{x}{Variable on the x-axis (\code{var1})}
@@ -82,6 +83,7 @@ plotConf <- function(model,
                      vcov,
                      predictfun,
                      plot=TRUE,
+                     new=TRUE,
                      ...) {
 
 
@@ -246,11 +248,13 @@ plotConf <- function(model,
     if (!plot) return(list(x=x, y=pr, predict=ci.all, predict.newdata=newdata))
 
     plot.list <- c(x=0,y=0,type="n",dots)
-    do.call(graphics::plot, plot.list)
-    if (is.null(var1)) {
-        box()
-        axis(2)
-        axis(1,at=seq(length(thelevels)),labels)
+    if (new) {
+        do.call(graphics::plot, plot.list)
+        if (is.null(var1)) {
+            box()
+            axis(2)
+            axis(1,at=seq(length(thelevels)),labels)
+        }
     }
 
     col.trans <- Col(col,alpha)
